TypeOptions

Struct TypeOptions 

pub struct TypeOptions {
    pub type: Option<String>,
}
Message passed to vade containing the desired credential type. Does not perform action if type does not indicate credential type jwt. This can be done by passing “jwt” as the value for “type”.

Fields

type: Option<String>