pub struct TypeOptions {
pub type: Option<String>,
}Expand description
Message passed to vade containing the desired credential type. Does not perform action if type does not indicate credential type jwt. This can be done by passing “jwt” as the value for “type”.
Fields
type: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TypeOptions
impl<'de> Deserialize<'de> for TypeOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more